==> flutter_tim-0.2.4.tar.gz: ios/Classes/DimModel.m <==
//
//  DimModel.m
//  dim
//
#import "DimModel.h"

@implementation DimUser

+ (DimUser *)initWithTimUser:(TIMUserProfile *)timUserProfile {
    DimUser *dimUser = [[DimUser alloc]init];
    dimUser.identifier = timUserProfile.identifier;
    dimUser.nickName = timUserProfile.nickname;
    dimUser.faceURL = timUserProfile.faceURL;
    dimUser.selfSignature = [[NSString alloc]initWithData:timUserProfile.selfSignature  encoding:NSUTF8StringEncoding];
    dimUser.gender = timUserProfile.gender ? timUserProfile.gender : 1;
    dimUser.birthday = timUserProfile.birthday;
    dimUser.location = [[NSString alloc]initWithData:timUserProfile.location  encoding:NSUTF8StringEncoding];
    return dimUser;
}

@end

@implementation DimConversation

+ (DimConversation *)initWithTIMConversation:(TIMConversation *)timConversation {
    
    DimConversation *dimConversation = [[DimConversation alloc]init];
    dimConversation.identifier = timConversation.getReceiver;
    

    dimConversation.conversationType = timConversation.getType;
    dimConversation.unReadNum = timConversation.getUnReadMessageNum;
    TIMMessage *lastMsg = timConversation.getLastMsg;
    TIMElem *elem = [lastMsg getElem:0];
    NSString * msg = @"";
    if ([elem isKindOfClass:[TIMTextElem class]]) {
        TIMTextElem * text_elem = (TIMTextElem * )elem;
        msg = text_elem.text;
    }
    else if ([elem isKindOfClass:[TIMImageElem class]]) {
        msg = @"[图片]";
    }
    else if ([elem isKindOfClass:[TIMSoundElem class]]){
        msg = @"[语音]";
    }
    else if ([elem isKindOfClass:[TIMVideoElem class]]){
        msg = @"[视频]";
    }
    else if ([elem isKindOfClass:[TIMFileElem class]]){
        msg = @"[文件]";
    }
    dimConversation.msg = msg;
    
    NSDate *date = lastMsg.timestamp;
    NSTimeInterval seconds = [date timeIntervalSinceReferenceDate];
    double milliseconds = seconds*1000;
    NSNumber *time = [NSNumber numberWithDouble:milliseconds];
    NSInteger timestamp = [time integerValue];
    dimConversation.sendTime = timestamp;
    
    
    
    return dimConversation;
}
@end

@implementation DimMessage

+ (DimMessage *)initWithTIMMessage:(TIMMessage *)timMessage {
    DimMessage *dimMessage = [[DimMessage alloc]init];
    dimMessage.identifier = timMessage.sender;
    dimMessage.conversationType = timMessage.getConversation.getType;
    dimMessage.message = [timMessage getElem:0];
    dimMessage.isRead = timMessage.isReaded;
    dimMessage.isSelf = timMessage.isSelf;
   
    NSDate *date = timMessage.timestamp;
    NSTimeInterval seconds = [date timeIntervalSinceReferenceDate];
    double milliseconds = seconds*1000;
    NSNumber *time = [NSNumber numberWithDouble:milliseconds];
    NSInteger timestamp = [time integerValue];
    dimMessage.sendTime = timestamp;
    
    TIMElem *elem = [timMessage getElem:0];

    NSString * type = @"";
    if ([elem isKindOfClass:[TIMTextElem class]]) {
        type = @"Text";
    }
    else if ([elem isKindOfClass:[TIMImageElem class]]) {
        type = @"Image";
    }
    else if ([elem isKindOfClass:[TIMSoundElem class]]){
        type = @"Sound";
    }
    else if ([elem isKindOfClass:[TIMVideoElem class]]){
        type = @"Video";
    }
    else if ([elem isKindOfClass:[TIMFileElem class]]){
        type = @"File";
    }else{
        type = @"Text";
    }
    dimMessage.type = type;
    
    return dimMessage;
}
@end

==> flutter_tim-0.2.8.tar.gz: ios/Classes/DimModel.m <==
//
//  DimModel.m
//  dim
//
#import "DimModel.h"

@implementation DimUser

+ (DimUser *)initWithTimUser:(TIMUserProfile *)timUserProfile {
    DimUser *dimUser = [[DimUser alloc]init];
    dimUser.identifier = timUserProfile.identifier;
    dimUser.nickName = timUserProfile.nickname;
    dimUser.faceURL = timUserProfile.faceURL;
    dimUser.selfSignature = [[NSString alloc]initWithData:timUserProfile.selfSignature  encoding:NSUTF8StringEncoding];
    dimUser.gender = timUserProfile.gender ? timUserProfile.gender : 1;
    dimUser.birthday = timUserProfile.birthday;
    dimUser.location = [[NSString alloc]initWithData:timUserProfile.location  encoding:NSUTF8StringEncoding];
    return dimUser;
}

@end

@implementation DimConversation

+ (DimConversation *)initWithTIMConversation:(TIMConversation *)timConversation {
    
    DimConversation *dimConversation = [[DimConversation alloc]init];
    dimConversation.identifier = timConversation.getReceiver;
    

    dimConversation.conversationType = timConversation.getType;
    dimConversation.unReadNum = timConversation.getUnReadMessageNum;
    TIMMessage *lastMsg = timConversation.getLastMsg;
    TIMElem *elem = [lastMsg getElem:0];
    NSString * msg = @"";
    if ([elem isKindOfClass:[TIMTextElem class]]) {
        TIMTextElem * text_elem = (TIMTextElem * )elem;
        msg = text_elem.text;
    }
    else if ([elem isKindOfClass:[TIMImageElem class]]) {
        msg = @"[图片]";
    }
    else if ([elem isKindOfClass:[TIMSoundElem class]]){
        msg = @"[语音]";
    }
    else if ([elem isKindOfClass:[TIMVideoElem class]]){
        msg = @"[视频]";
    }
    else if ([elem isKindOfClass:[TIMFileElem class]]){
        msg = @"[文件]";
    }
    dimConversation.msg = msg;
    
    NSDate *date = lastMsg.timestamp;
//    NSTimeInterval seconds = [date timeIntervalSinceReferenceDate];
    NSTimeInterval seconds = [date timeIntervalSince1970];
//    double milliseconds = seconds*1000;
    NSNumber *time = [NSNumber numberWithDouble:seconds];
    NSInteger timestamp = [time integerValue];
    dimConversation.sendTime = timestamp;
    
    
    
    return dimConversation;
}
@end

@implementation DimMessage

+ (DimMessage *)initWithTIMMessage:(TIMMessage *)timMessage {
    DimMessage *dimMessage = [[DimMessage alloc]init];
    dimMessage.identifier = timMessage.sender;
    dimMessage.conversationType = timMessage.getConversation.getType;
    dimMessage.message = [timMessage getElem:0];
    dimMessage.isRead = timMessage.isReaded;
    dimMessage.isSelf = timMessage.isSelf;
   
    NSDate *date = timMessage.timestamp;
//    NSTimeInterval seconds = [date timeIntervalSinceReferenceDate];
    NSTimeInterval seconds = [date timeIntervalSince1970];
//    double milliseconds = seconds*1000;
    NSNumber *time = [NSNumber numberWithDouble:seconds];
    NSInteger timestamp = [time integerValue];
    dimMessage.sendTime = timestamp;
    
    TIMElem *elem = [timMessage getElem:0];

    NSString * type = @"";
    if ([elem isKindOfClass:[TIMTextElem class]]) {
        type = @"Text";
    }
    else if ([elem isKindOfClass:[TIMImageElem class]]) {
        type = @"Image";
    }
    else if ([elem isKindOfClass:[TIMSoundElem class]]){
        type = @"Sound";
    }
    else if ([elem isKindOfClass:[TIMVideoElem class]]){
        type = @"Video";
    }
    else if ([elem isKindOfClass:[TIMFileElem class]]){
        type = @"File";
    }else{
        type = @"Text";
    }
    dimMessage.type = type;
    
    return dimMessage;
}
@end
